# frozen_string_literal: true

require 'bridge_api/version'
require 'bridge_api/client'

module BridgeAPI
  class << self
    require 'logger'
    attr_writer :enforce_rate_limits, :beginning_rate_limit, :rate_limits, :max_sleep_seconds, :min_sleep_seconds,
                :logger, :master_rate_limit, :master_mutex, :rate_limit_threshold

    def configure
      yield self if block_given?
    end

    def enforce_rate_limits
      @enforce_rate_limits ||= false
    end

    def beginning_rate_limit
      @beginning_rate_limit ||= 30
    end

    def rate_limits
      @rate_limits ||= {}
    end

    def max_sleep_seconds
      @max_sleep_seconds ||= 30
    end

    def master_rate_limit
      @master_rate_limit ||= false
    end

    def master_mutex
      @master_mutex ||= Mutex.new
    end

    def rate_limit_threshold
      @rate_limit_threshold ||= 10
    end

    def logger
      return @logger if defined? @logger
      @logger = Logger.new(STDOUT)
      @logger.level = :debug
      @logger
    end

    def min_sleep_seconds
      @min_sleep_seconds ||= 5
    end
  end
end
