# frozen_string_literal: true

module BridgeAPI
  class Client
    module SubAccount
      def get_sub_accounts(params = {})
        path = "#{API_PATH}#{ADMIN_PATH}#{SUB_ACCOUNT_PATH}"
        RESULT_MAPPING[path] = {
            meta: %w[data_dump_enabled data_dump_subaccount_enabled]
        }
        get(path, params)
      end

      def get_sub_account(subaccount_id, params = {})
        get("#{API_PATH}#{ADMIN_PATH}#{SUB_ACCOUNT_PATH}/#{subaccount_id}", params)
      end

      def deactivate_sub_account(subaccount_id, params = {})
        put("#{API_PATH}#{ADMIN_PATH}#{SUB_ACCOUNT_PATH}/#{subaccount_id}/disable", params)
      end

      def activate_sub_account(subaccount_id, params = {})
        put("#{API_PATH}#{ADMIN_PATH}#{SUB_ACCOUNT_PATH}/#{subaccount_id}/enable", params)
      end

      def update_subaccount(subaccount_id, params = {})
        put("#{API_PATH}#{ADMIN_PATH}#{SUB_ACCOUNT_PATH}/#{subaccount_id}", params)
      end

      def update_subaccount_auth(params = {})
        put("#{API_PATH}/config/sub_account/auth", params)
      end

      def share_course_with_subaccount(course_template_id, params = {})
        put("#{API_PATH}#{AUTHOR_PATH}#{COURSE_TEMPLATE_PATH}/#{course_template_id}/#{SUB_ACCOUNT_PATH}/share", params)
      end

      def async_share_course_with_subaccount(course_template_id, params = {})
        put("#{API_PATH}#{AUTHOR_PATH}#{AFFILIATED_SUBACCOUNTS}/share_async", params)
      end

      def revoke_course_from_subaccount(course_template_id, params = {})
        put("#{API_PATH}#{AUTHOR_PATH}#{COURSE_TEMPLATE_PATH}/#{course_template_id}/#{SUB_ACCOUNT_PATH}/revoke", params)
      end

      def get_lti_config_for_sub_account(sub_account_id, params = {})
        get("#{API_PATH}#{SUPPORT_PATH}#{SUB_ACCOUNT_PATH}/#{sub_account_id}#{LTI_TOOLS_PATH}", params)
      end

      def update_sub_account_lti_config(sub_account_id, lti_tool_id, params = {})
        put("#{API_PATH}#{SUPPORT_PATH}#{SUB_ACCOUNT_PATH}/#{sub_account_id}#{LTI_TOOLS_PATH}/#{lti_tool_id}", params)
      end

      def create_sub_account_lti_config(sub_account_id, params = {})
        post("#{API_PATH}#{SUPPORT_PATH}#{SUB_ACCOUNT_PATH}/#{sub_account_id}#{LTI_TOOLS_PATH}", params)
      end

      def delete_lti_config(sub_account_id, lti_tool_id, params = {})
        delete("#{API_PATH}#{SUPPORT_PATH}#{SUB_ACCOUNT_PATH}/#{sub_account_id}#{LTI_TOOLS_PATH}/#{lti_tool_id}", params)
      end

      def upsert_custom_attribute_values(sub_account_id, params = {})
        put("#{API_PATH}#{ADMIN_PATH}#{SUB_ACCOUNT_PATH}/#{sub_account_id}/custom_attribute_values", params)
      end
    end
  end
end
